==> plasma-workspace-5.1.2.tar.xz: plasma-workspace-5.1.2/shell/packageplugins/shell/shellpackage.h <==
/******************************************************************************
*   Copyright 2013 Marco Martin <notmart@gmail.com>                           *
*                                                                             *
*   This library is free software; you can redistribute it and/or             *
*   modify it under the terms of the GNU Library General Public               *
*   License as published by the Free Software Foundation; either              *
*   version 2 of the License, or (at your option) any later version.          *
*                                                                             *
*   This library is distributed in the hope that it will be useful,           *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
*   Library General Public License for more details.                          *
*                                                                             *
*   You should have received a copy of the GNU Library General Public License *
*   along with this library; see the file COPYING.LIB.  If not, write to      *
*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
*   Boston, MA 02110-1301, USA.                                               *
*******************************************************************************/

#ifndef SHELLPACKAGE_PLUGIN_H
#define SHELLPACKAGE_PLUGIN_H

#include <Plasma/PackageStructure>

class ShellPackage: public Plasma::PackageStructure
{
public:
    ShellPackage(QObject *parent, const QVariantList &list);
    void initPackage(Plasma::Package *package);
    void pathChanged(Plasma::Package *package);
};

#endif // SHELLPACKAGE_PLUGIN_H

==> plasma-workspace-5.5.4.tar.xz: plasma-workspace-5.5.4/shell/packageplugins/shell/shellpackage.h <==
/******************************************************************************
*   Copyright 2013 Marco Martin <notmart@gmail.com>                           *
*                                                                             *
*   This library is free software; you can redistribute it and/or             *
*   modify it under the terms of the GNU Library General Public               *
*   License as published by the Free Software Foundation; either              *
*   version 2 of the License, or (at your option) any later version.          *
*                                                                             *
*   This library is distributed in the hope that it will be useful,           *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
*   Library General Public License for more details.                          *
*                                                                             *
*   You should have received a copy of the GNU Library General Public License *
*   along with this library; see the file COPYING.LIB.  If not, write to      *
*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
*   Boston, MA 02110-1301, USA.                                               *
*******************************************************************************/

#ifndef SHELLPACKAGE_PLUGIN_H
#define SHELLPACKAGE_PLUGIN_H

#include <KPackage/PackageStructure>

class ShellPackage: public KPackage::PackageStructure
{
public:
    ShellPackage(QObject *parent, const QVariantList &list);
    void initPackage(KPackage::Package *package);
    void pathChanged(KPackage::Package *package);
};

#endif // SHELLPACKAGE_PLUGIN_H
